/**************************************************************
 * Blynk is a platform with iOS and Android apps to control
 * Arduino, Raspberry Pi and the likes over the Internet.
 * You can easily build graphic interfaces for all your
 * projects by simply dragging and dropping widgets.
 *
 *   Downloads, docs, tutorials: http://www.blynk.cc
 *   Blynk community:            http://community.blynk.cc
 *   Social networks:            http://www.fb.com/blynkapp
 *                               http://twitter.com/blynk_app
 *
 * Blynk library is licensed under MIT license
 * This example code is in public domain.
 *
 **************************************************************
 * This example runs directly on ESP8266 chip.
 *
 * You need to install this for ESP8266 development:
 *   https://github.com/esp8266/Arduino
 *
 * Change WiFi ssid, pass, and Blynk auth token to run :)
 *
 **************************************************************/

#define BLYNK_PRINT Serial    // Comment this out to disable prints and save space
#include <ESP8266WiFi.h>
#include <BlynkSimpleEsp8266.h>
#include <SimpleTimer.h>
#include <dht11.h>
#include <RCSwitch.h>
#include "LedControl.h" //  need the library
#define DHT11_PIN 12  //(D6)
LedControl lc=LedControl(5,0,4,1); // Pin 5(D1) connected to DIN; Pin 0(D3) connected to CLK; Pin 4(D2) connected to CS; 1 quantity of max7219 modules
dht11 DHT;

  float chk; 
  float temp;
  float hum;
  int LDR = A0;
  int ones;
  int tens;
  int hundreds;
  int v;
  float diff;
  int fones,ftens;
  
RCSwitch mySwitch = RCSwitch();
SimpleTimer timer;

char auth[] = "*******"; //insert here your token generated by Blynk


void sendUptime(){
  
  // You can send any value at any time.
  // Please don't send more that 10 values per second.
  chk = DHT.read(DHT11_PIN);    // READ DATA
  temp = DHT.temperature - 3;
  hum = DHT.humidity - 17;
  Blynk.virtualWrite(10, temp); //virtual pin for blynk V10
  Blynk.virtualWrite(11, hum); // virtual pin for blynk V11
  LDR = analogRead(LDR);
  Blynk.virtualWrite(0, LDR);
}

void setup(){
  
  Serial.begin(9600);
  Blynk.begin(auth, "******", "******"); //insert here your SSID and password
  pinMode(LDR, INPUT);
  mySwitch.setPulseLength(332); // pulselength for the rf433 modul
  mySwitch.setProtocol(1);      //Protocol version #1 
  mySwitch.enableTransmit(13); // pin GPI013(D7)
  timer.setInterval(1000L, sendUptime); 
  lc.shutdown(0,false);// turn off power saving, enables display
  lc.setIntensity(0,2);// sets brightness (0~15 possible values)
  lc.clearDisplay(0);// clear screen
}

void printNumber(float temp){
  
  v=temp;
  diff=temp-v;
  diff=diff*100;
  fones=(int)diff%10;
  diff=diff/10;
  ftens=(int)diff%10;
  diff=diff/10;
  ones=v%10;
  v=v/10;
  tens=v%10;
  v=v/10;
  hundreds=v;  
  //Now print the number digit by digit
 
  lc.setDigit(0,3,(byte)tens,false);
  lc.setDigit(0,2,(byte)ones,true);
  lc.setDigit(0,1,(byte)ftens,false);
  lc.setChar(0,0,'C',false);
}

void printNumber1(float hum){
  
  v=hum;
  diff=hum-v;
  diff=diff*100;
  fones=(int)diff%10;
  diff=diff/10;
  ftens=(int)diff%10;
  diff=diff/10;
  ones=v%10;
  v=v/10;
  tens=v%10;
  v=v/10;
  hundreds=v;  
  //Now print the number digit by digit
  
  lc.setDigit(0,7,(byte)tens,false);
  lc.setDigit(0,6,(byte)ones,true);
  lc.setDigit(0,5,(byte)ftens,false);
  lc.setChar(0,4,'F',false);
}

void loop(){
  
  Blynk.run();
  timer.run(); // Initiates SimpleTimer
  printNumber(temp);
  printNumber1(hum);
}

//-------rcswitch------
BLYNK_WRITE(0) {  //virtual pin 0
 mySwitch.send(279889, 24); // for decimal code first= decimal, second= Bit (24)
 delay(500);
}

BLYNK_WRITE(1) {
  mySwitch.send(279892, 24); // first switch Off
  delay(500);
}

BLYNK_WRITE(2) { 
 mySwitch.send(282961, 24); // second switch On
 delay(500);
}

BLYNK_WRITE(3) {
  mySwitch.send(282964, 24);  // second switch Off
  delay(500);
}

BLYNK_WRITE(4) {
 mySwitch.send(283729, 24); // third switch On
 delay(500);
}

BLYNK_WRITE(5) {
  mySwitch.send(283732, 24);  // third switch Off
  delay(500);
}

BLYNK_WRITE(6) {
  mySwitch.send(283921, 24);  //fourth switch On
  delay(500);
}

BLYNK_WRITE(7) {
  mySwitch.send(283924, 24);  //fourth switch Off
  delay(500);
}

BLYNK_WRITE(8) {
  mySwitch.send(283969, 24);  //fifth switch On
  delay(500);
}

BLYNK_WRITE(9) {
  mySwitch.send(283972, 24);  //fifth switch Off
  delay(500);
}
